@@ -28,10 +28,12 @@ def j(path):
     newpath = Popen(
         cmd,
         stdout=PIPE,
-        shell=False).communicate()[0].strip()
+        shell=False,
+    ).communicate()[0].strip()
 
     if newpath:
         ip.magic('cd %s' % newpath.decode('utf-8'))
 
+
 # remove from namespace
 del j
